@@ -1,6 +1,9 @@
+use strict;
+use warnings;
+
 package Perl::PrereqScanner::Scanner;
 BEGIN {
-  $Perl::PrereqScanner::Scanner::VERSION = '0.101892';
+  $Perl::PrereqScanner::Scanner::VERSION = '1.001';
 }
 use Moose::Role;
 # ABSTRACT: something that scans for prereqs in a Perl document
@@ -13,9 +16,12 @@ requires 'scan_for_prereqs';
 # -- rjbs, 2010-04-06
 sub _q_contents {
   my ($self, $token) = @_;
-  my @contents = $token->isa('PPI::Token::QuoteLike::Words')
-    ? ( $token->literal )
-    : ( $token->string  );
+  my @contents;
+  if ( $token->isa('PPI::Token::QuoteLike::Words') || $token->isa('PPI::Token::Number') ) {
+    @contents = $token->literal;
+  } else {
+    @contents = $token->string;
+  }
 
   return @contents;
 }
@@ -31,7 +37,7 @@ Perl::PrereqScanner::Scanner - something that scans for prereqs in a Perl docume
 
 =head1 VERSION
 
-version 0.101892
+version 1.001
 
 =head1 DESCRIPTION
 
@@ -48,17 +54,8 @@ its findings about the PPI document.
 
 =head1 AUTHORS
 
-=over 4
-
-=item *
-
-Jerome Quelin
-
-=item *
-
-Ricardo Signes <rjbs@cpan.org>
-
-=back
+  Jerome Quelin
+  Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
